@@ -41,7 +41,7 @@ def close_exact(data,point,radius_buffer):
 
 def cost_angles(angles):
     #func = lambda x: np.tanh(-(x+np.arctanh(np.log(2))))+np.log(1+np.exp(-x))
-    func = lambda x: np.log(1+np.exp(-x))
+    func = lambda x: np.log(1+np.exp(-x*100))
     return np.sum(func(angles))
 
 def get_all_vectors(pts):
