@@ -1,6 +1,6 @@
 run_0d_script="""import os
 import sys
 sys.path.append('{}')
-from svZeroDSolver import svzerodsolver
+import svzerodsolver
 svzerodsolver.solver.set_up_and_run_0d_simulation('{}')
 """
